aboutsummaryrefslogtreecommitdiffstats
path: root/java-overridable/src/com/android
diff options
context:
space:
mode:
Diffstat (limited to 'java-overridable/src/com/android')
-rw-r--r--java-overridable/src/com/android/inputmethod/latin/define/ProductionFlags.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/java-overridable/src/com/android/inputmethod/latin/define/ProductionFlags.java b/java-overridable/src/com/android/inputmethod/latin/define/ProductionFlags.java
index 43675682d..f31c20822 100644
--- a/java-overridable/src/com/android/inputmethod/latin/define/ProductionFlags.java
+++ b/java-overridable/src/com/android/inputmethod/latin/define/ProductionFlags.java
@@ -45,9 +45,10 @@ public final class ProductionFlags {
public static final boolean ENABLE_ACCOUNT_SIGN_IN = false;
/**
* When {@code true}, personal dictionary sync feature is ready to be enabled.
*/
- public static final boolean ENABLE_PERSONAL_DICTIONARY_SYNC = ENABLE_ACCOUNT_SIGN_IN && false;
+ public static final boolean ENABLE_USER_HISTORY_DICTIONARY_SYNC =
+ ENABLE_ACCOUNT_SIGN_IN && false;
/**
* When {@code true}, the IME maintains per account {@link UserHistoryDictionary}.
@@ -45,9 +45,10 @@ public final class ProductionFlags {
public static final boolean ENABLE_ACCOUNT_SIGN_IN = false;
/**
- * When {@code true}, personal dictionary sync feature is ready to be enabled.
+ * When {@code true}, user history dictionary sync feature is ready to be enabled.
*/